@@ -110,7 +110,7 @@ class Fullenv:
 
     async def load_client(self, clientname):
         filename = await self.client_config(clientname)
-        confdict = yaml.load(open(filename, "rb"))
+        confdict = yaml.load(open(filename, "rb"), Loader=yaml.Loader)
         return xbus.client.Client(
             confdict, os.path.dirname(filename), self.loop
         )
